diff --git a/src/pages/details/otherBussStandardDetails/index.vue b/src/pages/details/otherBussStandardDetails/index.vue
index 31272db5e..ec2303410 100644
--- a/src/pages/details/otherBussStandardDetails/index.vue
+++ b/src/pages/details/otherBussStandardDetails/index.vue
@@ -334,6 +334,7 @@
更新记录
标准问答
+ 标准需求(翻译)申请流程
diff --git a/src/pages/details/otherStandardDetails/index.vue b/src/pages/details/otherStandardDetails/index.vue
index bbf33b75f..c2ccd263e 100644
--- a/src/pages/details/otherStandardDetails/index.vue
+++ b/src/pages/details/otherStandardDetails/index.vue
@@ -37,6 +37,7 @@
@click="collectClick()">
更新记录
标准问答
+ 标准需求(翻译)申请流程
diff --git a/src/pages/home2/components/todoList/index.vue b/src/pages/home2/components/todoList/index.vue
index c924b4856..d0fb3b692 100644
--- a/src/pages/home2/components/todoList/index.vue
+++ b/src/pages/home2/components/todoList/index.vue
@@ -12,6 +12,15 @@
{{ getPrcNameFilter(item) }}
+
接受任务
@@ -61,6 +70,44 @@ export default {
toPage() {
this.$router.push(this.path)
},
+ // 接受按钮
+ handleReceive(item) {
+ this.isSubmit = true
+ // execTask({
+ // todoId: this.todoId // 当前节点ID
+ // }).then(res => {
+ // if (res.sign && res.sign === '0') {
+ // this.$message.success('接收成功')
+ // this.$router.push('/processCenter')
+ // }
+ // this.isSubmit = false
+ // })
+ // if(!this.tableData.standardData[0]){
+ // this.$message.warning('请先选择企标计划')
+ // this.isSubmit = false
+ // return
+ // }
+ this.$http.get("lawss/activiti/selectBusProcessNew", {
+ taskId: item.taskIds,
+ }, {
+ _this: this
+ }, res => {
+ this.$http.get("lawss/activiti/acceptTack", {
+ nowEsId: res,
+ oaFlag: '0',
+ taskId: item.taskIds,
+ }, {
+ _this: this
+ }, res => {
+ // if (res.sign && res.sign === '0') {
+ this.$message.success('接收成功')
+ this.isSubmit = false
+ this.showreceive = false
+ // this.$router.push('/processCenter')
+ // }
+ })
+ })
+ },
dealWith (row) { // 办理
const prcType = row.prcType
switch(prcType) {
@@ -1943,6 +1990,18 @@ export default {
}
})
}
+ case '27':
+ this.$router.push({
+ name: 'MyQuestions',
+ query:{
+ taskIds: row.taskIds,
+ prcId: row.prcId,
+ prcNum: row.prcNum,
+ prcName: row.prcName,
+ prcType: row.prcType,
+
+ }
+ })
break
}
diff --git a/src/pages/personal/pages/my-collection/components/CollectionBreak.vue b/src/pages/personal/pages/my-collection/components/CollectionBreak.vue
index 6b3caf6f2..2c3d58600 100644
--- a/src/pages/personal/pages/my-collection/components/CollectionBreak.vue
+++ b/src/pages/personal/pages/my-collection/components/CollectionBreak.vue
@@ -41,16 +41,17 @@
-
+
所属板块:{{ item.collectType === 'STAND_SPLIT' ? '标准拆分' : '标准拆分' }}
-
+
标题:{{ item.collectTitle }}
- 创建时间:{{item.creationTime}}
+ 状态:{{ item.validFlag == 0 ? '有效' : '无效'}}
+ 创建时间:{{item.creationTime}}
{{$t('m.cancelCollection')}}
diff --git a/src/pages/personal/pages/my-collection/components/CollectionDynamics.vue b/src/pages/personal/pages/my-collection/components/CollectionDynamics.vue
index d24036fa2..9350ae9ac 100644
--- a/src/pages/personal/pages/my-collection/components/CollectionDynamics.vue
+++ b/src/pages/personal/pages/my-collection/components/CollectionDynamics.vue
@@ -41,16 +41,17 @@
-
+
所属板块:{{ item.collectType === 'INLAND_MSG' ? '动态信息' : '资料中心' }}
-
+
标题:{{ item.collectTitle }}
- 创建时间:{{getDate(item.creationTime)}}
+ 状态:{{ item.validFlag == 0 ? '有效' : '无效'}}
+ 创建时间:{{getDate(item.creationTime)}}
{{$t('m.cancelCollection')}}
diff --git a/src/pages/personal/pages/my-collection/components/CollectionLaws.vue b/src/pages/personal/pages/my-collection/components/CollectionLaws.vue
index cc5250942..4a67575ec 100644
--- a/src/pages/personal/pages/my-collection/components/CollectionLaws.vue
+++ b/src/pages/personal/pages/my-collection/components/CollectionLaws.vue
@@ -40,16 +40,17 @@
-
+
所属板块:{{ '国内外政策' }}
-
+
标题:{{ item.collectTitle }}
- 创建时间:{{getDate(item.creationTime)}}
+ 状态:{{ item.validFlag == 0 ? '有效' : '无效'}}
+ 创建时间:{{getDate(item.creationTime)}}
取消收藏
diff --git a/src/pages/personal/pages/my-collection/components/CollectionStandard.vue b/src/pages/personal/pages/my-collection/components/CollectionStandard.vue
index 0d956b6d5..fb2c396d9 100644
--- a/src/pages/personal/pages/my-collection/components/CollectionStandard.vue
+++ b/src/pages/personal/pages/my-collection/components/CollectionStandard.vue
@@ -49,19 +49,20 @@
-
+
所属板块:{{ item.collectType === 'INLAND_STAND' ? '国内标准法规' : (item.collectType === 'FOREIGN_STAND' ? '海外标准法规' : '企业标准') }}
-
+
- 标题:{{ item.collectTitle }}
+ 标题:
标题:{{ item.collectTitle }}
- 创建时间:{{getDate(item.creationTime)}}
+ 状态:{{ item.validFlag == 0 ? '有效' : '无效'}}
+ 创建时间:{{getDate(item.creationTime)}}
diff --git a/src/pages/personal/pages/my-questions/components/answerItem.vue b/src/pages/personal/pages/my-questions/components/answerItem.vue
index 8fe10d24b..c1254be4d 100644
--- a/src/pages/personal/pages/my-questions/components/answerItem.vue
+++ b/src/pages/personal/pages/my-questions/components/answerItem.vue
@@ -68,6 +68,26 @@
点击或拖拽上传文件
+
+
+
+
+
@@ -84,10 +104,18 @@ export default {
return{
roleFlag: false,
nodeList: [],
+ flag:'',
mergeSelectList: [],
// 上传地址
actionPath: 'api/att/attFile/uploadNew',
importModalshowflagtemp: false,
+ submitBtnLoading: false,
+ dialogVisible: false,
+ queList:[],
+ queRules:{},
+ questionForm:{
+ problemDescription: '', //回答
+ },
fileList: [],
form:{
reply: '',
@@ -116,6 +144,12 @@ export default {
this.$http.postData('lawss/Reply/insertReply',{ ...this.form },{
_this: this
}, res => {
+ this.$http.post("lawss/activiti/completeTask", {
+ json: JSON.stringify(this.form),
+ taskId: this.$route.query.taskIds,
+ userId: this.$store.getters.userInfo.userId
+ }, {}, res => {
+ });
if(res.respCode === '200'){
this.form.reply = ''
this.fileList = []
@@ -178,28 +212,35 @@ export default {
}
})
},
+ handleClose(){
+ this.queList = []
+ this.dialogVisible = false
+ },
+ queSubmit(){
+ console.log(this.queList);
+ let queList = JSON.stringify(this.queList)
+ this.$emit('emitInsState',false)
+ this.$http.postData('lawss/Reply/updateReply',queList,
+ {
+ _this: this
+ }, res => {
+ if(res.respCode === '200'){
+ this.$emit('emitInsState',true)
+ }
+ }, e => {
+ })
+ },
//问题归档
queArchive(){
- let list = []
+ console.log(this.mergeSelectList);
this.mergeSelectList = this.mergeSelectList.filter ( item => item.state !== 'yes' && item.checked);
for (let i = 0; i < this.mergeSelectList.length; i++) {
if(this.mergeSelectList[i].checked){
- list.push(this.mergeSelectList[i].id)
+ this.queList.push(this.mergeSelectList[i])
}
}
- if(this.mergeSelectList && this.mergeSelectList.length > 0){
- this.$emit('emitInsState',false)
- let listId = list.join(',')
- this.$http.post('lawss/Reply/updateReply', {
- id: listId,
- },{
- _this: this
- }, res => {
- if(res.respCode === '200'){
- this.$emit('emitInsState',true)
- }
- }, e => {
- })
+ if(this.queList && this.queList.length > 0){
+ this.dialogVisible = true
}else {
this.$message.warning('请选择归档内容')
}
@@ -209,8 +250,8 @@ export default {
this.$emit('roleFlagBoo',true)
},
},
- mounted () {
- this.mergeSelectList = this.list
+ created () {
+ this.mergeSelectList = JSON.parse(JSON.stringify(this.list))
},
};
diff --git a/src/pages/personal/pages/my-questions/components/questionItemInfo.vue b/src/pages/personal/pages/my-questions/components/questionItemInfo.vue
index 2db8bdde9..a6a033a1e 100644
--- a/src/pages/personal/pages/my-questions/components/questionItemInfo.vue
+++ b/src/pages/personal/pages/my-questions/components/questionItemInfo.vue
@@ -58,7 +58,7 @@ export default {
institutionId: this.$store.getters.userInfo.institutionId,
answererNowUserId: this.$store.getters.userInfo.userId,
answererNowUserName: this.$store.getters.userInfo.userName,
- fileList:[],
+ // fileList:[],
}
},
methods:{
diff --git a/src/pages/personal/pages/my-questions/index.vue b/src/pages/personal/pages/my-questions/index.vue
index e4f269600..007bba784 100644
--- a/src/pages/personal/pages/my-questions/index.vue
+++ b/src/pages/personal/pages/my-questions/index.vue
@@ -823,6 +823,12 @@
diff --git a/src/pages/processCenter/pages/creatProcess/bzpg/step5.vue b/src/pages/processCenter/pages/creatProcess/bzpg/step5.vue
index e9a6301d8..65d19c8b2 100644
--- a/src/pages/processCenter/pages/creatProcess/bzpg/step5.vue
+++ b/src/pages/processCenter/pages/creatProcess/bzpg/step5.vue
@@ -900,7 +900,7 @@ export default {
return
})
if(submitFlag === 0 ){
- this.$message.warning('请至少对一条信息进行评估')
+ this.$message.warning('请对所有信息进行评估')
}else{
this.handlePrice()
if(this.comFlag > 0) {
diff --git a/src/pages/processCenter/pages/creatProcess/bzrk/step1.vue b/src/pages/processCenter/pages/creatProcess/bzrk/step1.vue
index b89e17c62..b29432904 100644
--- a/src/pages/processCenter/pages/creatProcess/bzrk/step1.vue
+++ b/src/pages/processCenter/pages/creatProcess/bzrk/step1.vue
@@ -1957,6 +1957,11 @@
this.checkIsOnly()
}
},
+ 'form.standName' : {
+ handler: function() {
+ this.checkIsOnly()
+ }
+ },
'form.standNumber' : {
handler: function() {
this.checkIsOnly()
@@ -2129,34 +2134,36 @@
}
if (this.form.standInData === '0') {
standType = 'INLAND'
- if(this.form.standSort && this.form.standNumber && this.form.standYear){
+ if(this.form.standSort && this.form.standNumber && this.form.standYear && this.form.standName){
this.$http.get('sarStandardsInfo/sar-standards-info/checkIsOnly', {
standType: standType,
standSort: this.form.standSort,
+ standName: this.form.standName,
standNumber: this.form.standNumber,
standYear: this.form.standYear,
}, {
_this: this
}, res => {
if (!res.ok) {
- this.$message.warning('标准号重复')
+ this.$message.warning(res.message)
return
}
})
}
} else {
standType = 'FOREIGN'
- if(this.form.standSort && this.form.standNumber){
+ if(this.form.standSort && this.form.standNumber && this.form.standName){
this.$http.get('sarStandardsInfo/sar-standards-info/checkIsOnly', {
standType: standType,
standSort: this.form.standSort,
+ standName: this.form.standName,
standNumber: this.form.standNumber,
standYear: this.form.standYear,
}, {
_this: this
}, res => {
if (!res.ok) {
- this.$message.warning('标准号重复')
+ this.$message.warning(res.message)
return
}
})
@@ -2492,6 +2499,7 @@
handleProcessStandardNext(status) {
this.submitType = status
switch (status) {
+
// 新增
case 1:
this.gdType = '新增'
@@ -2500,8 +2508,8 @@
this.standardDrawer = false
this.verifySarStandard = true
// this.clearFormData(this.form)
- this.clearFormData()
- this.clearFileListData()
+ // this.clearFormData()
+ // this.clearFileListData()
break
// 带入(确认)
case 2:
@@ -3680,6 +3688,7 @@
this.$http.get('sarStandardsInfo/sar-standards-info/checkIsOnly', {
standType: standType,
standSort: this.form.standSort,
+ standName: this.form.standName,
standNumber: this.form.standNumber,
standYear: this.form.standYear,
}, {
@@ -3741,7 +3750,7 @@
}
})
} else {
- this.$message.warning('标准号重复')
+ this.$message.warning(res.message)
return
}
})
diff --git a/src/pages/processCenter/pages/creatProcess/bzzqyj/step4-1.vue b/src/pages/processCenter/pages/creatProcess/bzzqyj/step4-1.vue
index 41396263c..07ce5ed81 100644
--- a/src/pages/processCenter/pages/creatProcess/bzzqyj/step4-1.vue
+++ b/src/pages/processCenter/pages/creatProcess/bzzqyj/step4-1.vue
@@ -448,7 +448,7 @@
}
})
} else {
- this.$message.warning('请输入反馈意见')
+ this.$message.warning('请输审批意见')
}
},
diff --git a/src/pages/processCenter/pages/creatProcess/qbfs/step5.vue b/src/pages/processCenter/pages/creatProcess/qbfs/step5.vue
index f5ee6de53..1bdc9f3aa 100644
--- a/src/pages/processCenter/pages/creatProcess/qbfs/step5.vue
+++ b/src/pages/processCenter/pages/creatProcess/qbfs/step5.vue
@@ -678,7 +678,7 @@ export default {
}, e => {
});
}else {
- this.$message.warning('请检查基础信息表单是否填写完整')
+ this.$message.warning('请填写审批意见')
}
})
},
diff --git a/src/pages/processCenter/pages/creatProcess/qbrk/step1-2.vue b/src/pages/processCenter/pages/creatProcess/qbrk/step1-2.vue
index 362774300..9889e5400 100644
--- a/src/pages/processCenter/pages/creatProcess/qbrk/step1-2.vue
+++ b/src/pages/processCenter/pages/creatProcess/qbrk/step1-2.vue
@@ -3461,7 +3461,6 @@
_this: this
}, res => {
if (res.data === true) {
- console.log(1);
this.showreceive = true
} else {
this.showreceive = false
diff --git a/src/pages/processCenter/pages/processList/tabComponents/processCenter/index.vue b/src/pages/processCenter/pages/processList/tabComponents/processCenter/index.vue
index 39983ba25..399809b91 100644
--- a/src/pages/processCenter/pages/processList/tabComponents/processCenter/index.vue
+++ b/src/pages/processCenter/pages/processList/tabComponents/processCenter/index.vue
@@ -2227,6 +2227,18 @@ export default {
})
}
break
+ case '27':
+ this.$router.push({
+ name: 'MyQuestions',
+ query:{
+ taskIds: row.taskIds,
+ prcId: row.prcId,
+ prcNum: row.prcNum,
+ prcName: row.prcName,
+ prcType: row.prcType,
+
+ }
+ })
}
},
...mapMutations(['setProcess', 'setHandleInfo']),
diff --git a/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue b/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue
index 98bf00227..6832560ed 100644
--- a/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue
+++ b/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue
@@ -233,13 +233,12 @@
-
-
-
-
-
-
-
+ 导入
{
- if (boolean) {
- // this.$refs.importfile.clearFiles()
- if (flag === 1) {
- let menuId = this.selectSarMenu.id
- if (menuId == null || menuId === '') {
- this.$message({
- showClose: true,
- message: '请选择标准导入的目录',
- type: 'error'
- })
- } else {
- this.importModalshowflag = true
- this.showUploadlist = true
- this.importExcelUrl = '/api/lawss/sarBussionessStand/importZipSarBussionessStand?menuId=' + menuId
- }
- } else {
- this.importModalshowflag = true
- this.importExcelUrl = '/api/lawss/sarBussStandItems/importSarBussStandItemsList?standId=' + this.standItemSearch.standId
- }
- }
- })
+ this.importModalshowflag = true
+ this.showUploadlist = true
+ this.importExcelUrl = '/api/lawss/sarBussionessStand/importSarBussionessStandFile'
},
// 二级菜单新建,编辑,删除
clickDropMenu(name, treeNode) {
diff --git a/src/pages/regulatoryRepository/standQA/index.vue b/src/pages/regulatoryRepository/standQA/index.vue
index 0e2af757f..ccf4c45b0 100644
--- a/src/pages/regulatoryRepository/standQA/index.vue
+++ b/src/pages/regulatoryRepository/standQA/index.vue
@@ -102,6 +102,12 @@
选择标准
+
+ {{ questionForm.standSortShow }} {{questionForm.standNumber }}-{{ questionForm.standYear }}
+
+
+ {{questionForm.standardName}}
+
@@ -795,6 +801,9 @@ export default {
this.handleSelectTableList[0].standSortShow + this.handleSelectTableList[0].standNumber
}
this.questionForm.standardName = this.handleSelectTableList[0].standName
+ this.questionForm.standSortShow = this.handleSelectTableList[0].standSortShow
+ this.questionForm.standYear = this.handleSelectTableList[0].standYear
+ this.questionForm.standNumber = this.handleSelectTableList[0].standNumber
this.questionForm.standardId = this.handleSelectTableList[0].id
this.standModel = false
}else{
diff --git a/src/pages/searchCenter/pages/standardSearch.vue b/src/pages/searchCenter/pages/standardSearch.vue
index c85d5f7bc..95c032033 100644
--- a/src/pages/searchCenter/pages/standardSearch.vue
+++ b/src/pages/searchCenter/pages/standardSearch.vue
@@ -29,6 +29,10 @@
首页
+
+
+ 标准需求(翻译)申请流程
+
diff --git a/src/router/index.js b/src/router/index.js
index c18b79f5a..ce0cc379b 100644
--- a/src/router/index.js
+++ b/src/router/index.js
@@ -1508,6 +1508,15 @@ const routes = [
title: '标准调研流程'
}
},
+ // {
+ // path: '/bzxqfyStep1',
+ // name: 'bzxqfyStep1',
+ // component: () => import('@/pages/processCenter/pages/creatProcess/bzxqfy/step1.vue'),
+ // meta: {
+ // requireAuth: true,
+ // title: '标准翻译流程'
+ // }
+ // },
{
path: '/ZQYJAddFileDetails',
name: 'ZQYJAddFileDetails',
diff --git a/src/sysConfig/index.js b/src/sysConfig/index.js
index 4b5e53eb3..8bec9d854 100644
--- a/src/sysConfig/index.js
+++ b/src/sysConfig/index.js
@@ -1,30 +1,29 @@
-/**
- * @description: 通用配置
- * @author: chenxiaoxi
- * @date: 2018-09-04 17:47:46
- */
+/*** @description: 通用配置
+* @author: chenxiaoxi
+* @date: 2018-09-04 17:47:46
+*/
// 服务器地址
// const devIp = '39.98.140.126'
-// const devInterfacePORT = '10005'
-// const devIp = '192.168.10.6'
+// const devInterfacePORT = '4202'
+// const devIp = '192.168.1.42'
+// const devInterfacePORT = '9999'
+const devIp = '10.10.10.46'
+const devInterfacePORT = '4202'
+// // const devIp = '10.0.3.10'
+// const devIp = 'localhost'
+// const devInterfacePORT = '10086'
// const devIp = '62.234.136.153'
// const devInterfacePORT = '8033'
-const devIp = '10.19.11.243'
-const devInterfacePORT = '4304'
// 配置 idm 认证
const ssoLogin = 'http://sso.foton.com.cn/oauth2.0/authorize?client_id=app_slrs&response_type=code&redirect_uri='
-
-const ssoLogout = 'http://sso.foton.com.cn/logout?service='
// 配置 前端服务
-const devWebUrl = 'https://srms.foton.com.cn/#/'
+const devWebUrl = 'http://62.234.136.153:8038/#/'
// webLoginType : idm (线上统一登录) 、 webLoginType: dev (测试环境登录)
-const webLoginType = 'idm'
+const webLoginType = 'dev'
// 配置onlyOffice 前端服务
-const onlyOfficeUrl = 'http://10.100.5.116:8088'
-
-// 配置 kkFileView 前端服务
-const kkFileViewUrl = 'https://srms.foton.com.cn/preview'
+// const onlyOfficeUrl = 'http://127.0.0.1:8080'
+const onlyOfficeUrl = 'http://10.10.10.46:8889'
// 云端端口号
const DEV_CLOUD_RES_INTERFACE_PORT = '7777'
@@ -48,10 +47,12 @@ const processPort = '17210'
*****************************************************************/
// 生产环境配置
-// const prodIp = '62.234.136.153'
-// const prodInterfacePORT = '8033'
-const prodIp = 'srms.foton.com.cn'
-const prodInterfacePORT = ''
+// const prodIp = '39.98.140.126'
+// const prodInterfacePORT = '4201'
+const prodIp = '10.10.10.46'
+const prodInterfacePORT = '4202'
+// const prodIp = 'slrs.foton.com.cn'
+// const prodInterfacePORT = ''
// 判断环境
const serverIP = process.env.NODE_ENV === 'production' ? prodIp : devIp
@@ -59,16 +60,14 @@ const interfacePORT = process.env.NODE_ENV === 'production' ? prodInterfacePORT
const CLOUD_RES_INTERFACE_PORT = process.env.NODE_ENV === 'production' ? DEV_CLOUD_RES_INTERFACE_PORT : DEV_CLOUD_RES_INTERFACE_PORT
module.exports = {
- baseUrl: 'https://' + serverIP + ':' + interfacePORT,
+ baseUrl: 'http://' + serverIP + ':' + interfacePORT,
webLoginType: webLoginType,
ssoLoginUrlDev: ssoLogin + devWebUrl,
- ssoLogoutUrlDev: ssoLogout + devWebUrl,
ssoLoginUrl: ssoLogin,
onlyOfficeUrl: onlyOfficeUrl,
- kkFileViewUrl: kkFileViewUrl,
devWebUrl: devWebUrl,
- serverUrl: 'https://' + serverIP, // 服务器IP地址
- interfaceUrl: 'https://' + serverIP + ':' + interfacePORT + '/api/', // 服务器端接口访问地址,
+ serverUrl: 'http://' + serverIP, // 服务器IP地址
+ interfaceUrl: 'http://' + serverIP + ':' + interfacePORT + '/api/', // 服务器端接口访问地址,
cloudResInterFaceUrl: 'http://' + serverIP + ':' + interfacePORT + '/busApi/', // 云端资源库服务器端接口访问地址,
simpleUploadPath: 'api/' + simpleFilePath, // 单文件上传地址
multipleUploadPath: 'api/' + multipleFilePath, // 多文件上传地址
@@ -78,4 +77,4 @@ module.exports = {
enterprise: enterprise, // GQ广汽 SJZX数据中心
theme: theme, // 主题
processInterfaceURL: `http://${serverIP}:${processPort}/bat-wkflow`
-}
+}
\ No newline at end of file